/*
 * MOTIS API
 *
 * This is the MOTIS routing API.
 *
 * The version of the OpenAPI document: v1
 * Contact: felix@triptix.tech
 * Generated by: https://openapi-generator.tech
 */

use crate::models;
use serde::{Deserialize, Serialize};

#[derive(Clone, Default, Debug, PartialEq, Serialize, Deserialize)]
pub struct Footpaths200Response {
    #[serde(rename = "place")]
    pub place: Box<models::Place>,
    /// all outgoing footpaths of this location
    #[serde(rename = "footpaths")]
    pub footpaths: Vec<models::Footpath>,
}

impl Footpaths200Response {
    pub fn new(place: models::Place, footpaths: Vec<models::Footpath>) -> Footpaths200Response {
        Footpaths200Response {
            place: Box::new(place),
            footpaths,
        }
    }
}

